#[non_exhaustive]pub struct StartBotAnalyzerInput {
pub bot_id: Option<String>,
pub analysis_scope: Option<AnalysisScope>,
pub locale_id: Option<String>,
pub bot_version: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bot_id: Option<String>The unique identifier of the bot to analyze.
analysis_scope: Option<AnalysisScope>The scope of analysis to perform. Currently only BotLocale scope is supported.
Valid Values: BotLocale
locale_id: Option<String>The locale identifier for the bot locale to analyze. Required when analysisScope is BotLocale.
bot_version: Option<String>The version of the bot to analyze. Defaults to DRAFT if not specified.
Implementations
Sourceimpl StartBotAnalyzerInput
impl StartBotAnalyzerInput
Sourcepub fn analysis_scope(&self) -> Option<&AnalysisScope>
pub fn analysis_scope(&self) -> Option<&AnalysisScope>
The scope of analysis to perform. Currently only BotLocale scope is supported.
Valid Values: BotLocale
Sourcepub fn locale_id(&self) -> Option<&str>
pub fn locale_id(&self) -> Option<&str>
The locale identifier for the bot locale to analyze. Required when analysisScope is BotLocale.
Sourcepub fn bot_version(&self) -> Option<&str>
pub fn bot_version(&self) -> Option<&str>
The version of the bot to analyze. Defaults to DRAFT if not specified.
Sourceimpl StartBotAnalyzerInput
impl StartBotAnalyzerInput
Sourcepub fn builder() -> StartBotAnalyzerInputBuilder
pub fn builder() -> StartBotAnalyzerInputBuilder
Creates a new builder-style object to manufacture StartBotAnalyzerInput.