#[non_exhaustive]pub struct StartBotAnalyzerOutput {
pub bot_id: Option<String>,
pub bot_version: Option<String>,
pub locale_id: Option<String>,
pub bot_analyzer_status: Option<BotAnalyzerStatus>,
pub bot_analyzer_request_id: Option<String>,
pub creation_date_time: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bot_id: Option<String>The unique identifier of the bot being analyzed.
bot_version: Option<String>The version of the bot being analyzed.
locale_id: Option<String>The locale identifier of the bot locale being analyzed.
bot_analyzer_status: Option<BotAnalyzerStatus>The current status of the analysis. The initial status is Processing.
Valid Values: Processing | Available | Failed | Stopping | Stopped
bot_analyzer_request_id: Option<String>A unique identifier for this analysis request. Use this identifier to check the status and retrieve results.
creation_date_time: Option<DateTime>The date and time when the analysis was initiated.
Implementations
Sourceimpl StartBotAnalyzerOutput
impl StartBotAnalyzerOutput
Sourcepub fn bot_version(&self) -> Option<&str>
pub fn bot_version(&self) -> Option<&str>
The version of the bot being analyzed.
Sourcepub fn locale_id(&self) -> Option<&str>
pub fn locale_id(&self) -> Option<&str>
The locale identifier of the bot locale being analyzed.
Sourcepub fn bot_analyzer_status(&self) -> Option<&BotAnalyzerStatus>
pub fn bot_analyzer_status(&self) -> Option<&BotAnalyzerStatus>
The current status of the analysis. The initial status is Processing.
Valid Values: Processing | Available | Failed | Stopping | Stopped
Sourcepub fn bot_analyzer_request_id(&self) -> Option<&str>
pub fn bot_analyzer_request_id(&self) -> Option<&str>
A unique identifier for this analysis request. Use this identifier to check the status and retrieve results.
Sourcepub fn creation_date_time(&self) -> Option<&DateTime>
pub fn creation_date_time(&self) -> Option<&DateTime>
The date and time when the analysis was initiated.
Sourceimpl StartBotAnalyzerOutput
impl StartBotAnalyzerOutput
Sourcepub fn builder() -> StartBotAnalyzerOutputBuilder
pub fn builder() -> StartBotAnalyzerOutputBuilder
Creates a new builder-style object to manufacture StartBotAnalyzerOutput.