#[non_exhaustive]pub struct StopBotAnalyzerOutput {
pub bot_id: Option<String>,
pub bot_version: Option<String>,
pub locale_id: Option<String>,
pub bot_analyzer_status: Option<BotAnalyzerStatus>,
pub bot_analyzer_request_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bot_id: Option<String>The unique identifier of the bot.
bot_version: Option<String>The version of the bot.
locale_id: Option<String>The locale identifier of the bot locale.
bot_analyzer_status: Option<BotAnalyzerStatus>The updated status of the analysis. The status will be Stopping and will eventually transition to Stopped.
Valid Values: Processing | Available | Failed | Stopping | Stopped
bot_analyzer_request_id: Option<String>The unique identifier of the analysis request.
Implementations
Sourceimpl StopBotAnalyzerOutput
impl StopBotAnalyzerOutput
Sourcepub fn bot_version(&self) -> Option<&str>
pub fn bot_version(&self) -> Option<&str>
The version of the bot.
Sourcepub fn bot_analyzer_status(&self) -> Option<&BotAnalyzerStatus>
pub fn bot_analyzer_status(&self) -> Option<&BotAnalyzerStatus>
The updated status of the analysis. The status will be Stopping and will eventually transition to Stopped.
Valid Values: Processing | Available | Failed | Stopping | Stopped
Sourcepub fn bot_analyzer_request_id(&self) -> Option<&str>
pub fn bot_analyzer_request_id(&self) -> Option<&str>
The unique identifier of the analysis request.
Sourceimpl StopBotAnalyzerOutput
impl StopBotAnalyzerOutput
Sourcepub fn builder() -> StopBotAnalyzerOutputBuilder
pub fn builder() -> StopBotAnalyzerOutputBuilder
Creates a new builder-style object to manufacture StopBotAnalyzerOutput.