#[non_exhaustive]pub struct BotAnalyzerHistorySummary {
pub bot_analyzer_status: BotAnalyzerStatus,
pub creation_date_time: Option<DateTime>,
pub bot_analyzer_request_id: String,
}Expand description
Contains summary information about a historical bot analysis execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bot_analyzer_status: BotAnalyzerStatusThe status of the historical analysis execution.
Valid Values: Processing | Available | Failed | Stopping | Stopped
creation_date_time: Option<DateTime>The date and time when the analysis was initiated.
bot_analyzer_request_id: StringThe unique identifier for the analysis request.
Implementations
Sourceimpl BotAnalyzerHistorySummary
impl BotAnalyzerHistorySummary
Sourcepub fn bot_analyzer_status(&self) -> &BotAnalyzerStatus
pub fn bot_analyzer_status(&self) -> &BotAnalyzerStatus
The status of the historical analysis execution.
Valid Values: Processing | Available | Failed | Stopping | Stopped
Sourcepub fn creation_date_time(&self) -> Option<&DateTime>
pub fn creation_date_time(&self) -> Option<&DateTime>
The date and time when the analysis was initiated.
Sourcepub fn bot_analyzer_request_id(&self) -> &str
pub fn bot_analyzer_request_id(&self) -> &str
The unique identifier for the analysis request.
Sourceimpl BotAnalyzerHistorySummary
impl BotAnalyzerHistorySummary
Sourcepub fn builder() -> BotAnalyzerHistorySummaryBuilder
pub fn builder() -> BotAnalyzerHistorySummaryBuilder
Creates a new builder-style object to manufacture BotAnalyzerHistorySummary.