#[non_exhaustive]pub struct BotAnalyzerRecommendation {
pub issue_location: Option<IssueLocation>,
pub priority: Priority,
pub issue_description: String,
pub proposed_fix: String,
}Expand description
Contains a recommendation for bot optimization identified by the Bot Analyzer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.issue_location: Option<IssueLocation>The location information for the identified issue within the bot configuration.
priority: PriorityThe priority level of the recommendation.
Valid Values: High | Medium | Low
issue_description: StringA detailed description of the identified configuration issue.
proposed_fix: StringThe recommended solution to address the identified issue.
Implementations
Sourceimpl BotAnalyzerRecommendation
impl BotAnalyzerRecommendation
Sourcepub fn issue_location(&self) -> Option<&IssueLocation>
pub fn issue_location(&self) -> Option<&IssueLocation>
The location information for the identified issue within the bot configuration.
Sourcepub fn priority(&self) -> &Priority
pub fn priority(&self) -> &Priority
The priority level of the recommendation.
Valid Values: High | Medium | Low
Sourcepub fn issue_description(&self) -> &str
pub fn issue_description(&self) -> &str
A detailed description of the identified configuration issue.
Sourcepub fn proposed_fix(&self) -> &str
pub fn proposed_fix(&self) -> &str
The recommended solution to address the identified issue.
Sourceimpl BotAnalyzerRecommendation
impl BotAnalyzerRecommendation
Sourcepub fn builder() -> BotAnalyzerRecommendationBuilder
pub fn builder() -> BotAnalyzerRecommendationBuilder
Creates a new builder-style object to manufacture BotAnalyzerRecommendation.